DuplicateNameError class

Thrown when attempting to add a suffix with a name which has already been used.

Inheritance

Constructors

DuplicateNameError({required String name})
Create an instance.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The message to show.
finalinherited
name String
The duplicate name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited