DuplicateNameError class
Thrown when attempting to add a suffix with a name which has already been used.
- Inheritance
-
- Object
- EmoteUtilsError
- DuplicateNameError
Constructors
- DuplicateNameError({required String name})
- Create an instance.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited